:orphan:

API modules
===========

The following modules are provided for those who wish to extend natu, understand
its internal design, or interface with it at a low level:

- :mod:`natu.exponents` - Class and supporting functions to represent the
  product of factors with exponents
- :mod:`natu.core` - Core classes of natu
- :mod:`natu.util` - General supporting functions
